@@ -108,7 +108,7 @@ box_error( GtkWidget *par, const char *fmt, ... )
 	gtk_widget_show( GTK_WIDGET( idlg ) );
 }
 
-/* Mark up a top/sub pair.
+/* Mark up a top/sub pair for a dialog box.
  */
 static void
 box_vmarkup( char *out, const char *top, const char *sub, va_list ap )
@@ -163,15 +163,12 @@ box_alert( GtkWidget *par )
 /* Make an information dialog.
  */
 void
-box_info( GtkWidget *par, const char *top, const char *sub, ... )
+box_vinfo( GtkWidget *par, const char *top, const char *sub, va_list ap )
 {
-	va_list ap;
 	char buf[MAX_DIALOG_TEXT];
 	GtkWidget *idlg;
 
-        va_start( ap, sub );
 	box_vmarkup( buf, top, sub, ap );
-        va_end( ap );
 
 	idlg = idialog_new();
 	idialog_set_build( IDIALOG( idlg ), 
@@ -185,6 +182,18 @@ box_info( GtkWidget *par, const char *top, const char *sub, ... )
 	gtk_widget_show( GTK_WIDGET( idlg ) );
 }
 
+/* Make an information dialog.
+ */
+void
+box_info( GtkWidget *par, const char *top, const char *sub, ... )
+{
+	va_list ap;
+
+        va_start( ap, sub );
+	box_vinfo( par, top, sub, ap );
+        va_end( ap );
+}
+
 /* Pop up an 'Are you sure?' window. 
  */
 iDialog *
@@ -265,11 +274,9 @@ about_build( iDialog *idlg, GtkWidget *work )
 	GtkWidget *lab;
 	char txt[MAX_DIALOG_TEXT];
 	char txt2[MAX_DIALOG_TEXT];
-	VipsBuf buf;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 	GtkWidget *image;
 
-	vips_buf_init_static( &buf, txt, MAX_DIALOG_TEXT );
-
 	im_snprintf( txt2, MAX_DIALOG_TEXT, _( "About %s." ), PACKAGE );
 	vips_buf_appendf( &buf, "<b><big>%s</big></b>\n\n", txt2 );
 	im_snprintf( txt2, MAX_DIALOG_TEXT, 
@@ -387,7 +394,7 @@ box_help( GtkWidget *par, const char *name )
 
 	error_top( _( "Help page not found." ) );
 	error_sub( _( "No indexed help page found for tag \"%s\"" ), name );
-	box_alert( par );
+	iwindow_alert( par, GTK_MESSAGE_ERROR );
 }
 
 /* Name + caption dialog ... for new workspace / new column.
@@ -597,9 +604,9 @@ find_build( GtkWidget *widget )
 
 	find->search = build_glabeltext4( idlg->work, NULL, _( "Search for" ) );
 	find->csens = build_gtoggle( idlg->work, _( "Case sensitive" ) );
-#ifdef HAVE_REGEXEC
+#ifdef HAVE_GREGEX
 	find->regexp = build_gtoggle( idlg->work, _( "Regular expression" ) );
-#endif /*HAVE_REGEXEC*/
+#endif /*HAVE_GREGEX*/
 	find->fromtop = build_gtoggle( idlg->work, _( "Search from start" ) );
 	idialog_set_default_entry( idlg, GTK_ENTRY( find->search ) );
 	gtk_widget_show_all( idlg->work );
@@ -935,7 +942,7 @@ box_url( GtkWidget *par, const char *url )
 		error_top( _( "Unable to view help file." ) );
 		error_sub( _( "Unable to open URL \"%s\", "
 			"windows error code = %d." ), url, v );
-		box_alert( par );
+		iwindow_alert( par, GTK_MESSAGE_ERROR );
 	}
 #elif defined OS_DARWIN
 	(void) systemf( "open %s", url );
@@ -946,29 +953,29 @@ box_url( GtkWidget *par, const char *url )
 		error_top( _( "Unable to view help file." ) );
 		error_sub( _( "Attempt to view URL with xdg-open failed\n%s" ),
 			url );
-		box_alert( par );
+		iwindow_alert( par, GTK_MESSAGE_ERROR );
 	}
 	else if( !shown ) {
-		box_info( par, _( "Browser window opened." ),
+		error_top( _( "Browser window opened." ) );
+		error_sub( "%s", 
 			_( "You may need to switch desktops to see the "
 			"new window." ) );
+		iwindow_alert( par, GTK_MESSAGE_INFO );
 		shown = TRUE;
 	}
 #else /*default unix-y*/
 	static gboolean shown = FALSE;
 
-	VipsBuf buf;
 	char txt[512];
-	VipsBuf buf2;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 	char txt2[512];
+	VipsBuf buf2 = VIPS_BUF_STATIC( txt2 );
 
 	char url2[FILENAME_MAX];
 
 	expand_variables( url, url2 );
 
-	vips_buf_init_static( &buf, txt, 512 );
 	vips_buf_appendf( &buf, "%s %s", BOX_BROWSER, BOX_BROWSER_REMOTE );
-	vips_buf_init_static( &buf2, txt2, 512 );
 	vips_buf_appendf( &buf2, vips_buf_all( &buf ), url2 );
 
 	if( systemf( "%s", vips_buf_all( &buf2 ) ) ) {
@@ -978,13 +985,14 @@ box_url( GtkWidget *par, const char *url )
 			"  %s\n"
 			"You can change this command in Preferences." ),
 			vips_buf_all( &buf2 ) );
-		box_alert( par );
+		iwindow_alert( par, GTK_MESSAGE_ERROR );
 	}
 	else if( !shown ) {
-		box_info( par, 
-			_( "Browser window opened." ),
+		error_top( _( "Browser window opened." ) );
+		error_sub( "%s",
 			_( "You may need to switch desktops to see the "
 			"new window." ) );
+		iwindow_alert( par, GTK_MESSAGE_INFO );
 		shown = TRUE;
 	}
 #endif /*lots*/
@@ -1423,3 +1431,215 @@ fontbutton_get_font_name( Fontbutton *fontbutton )
 {
 	return( fontbutton->font_name );
 }
+
+/* Infobar.
+ */
+
+static GtkInfoBarClass *infobar_parent_class = NULL;
+
+static void
+infobar_destroy( GtkObject *object )
+{
+	Infobar *infobar;
+
+	g_return_if_fail( object != NULL );
+	g_return_if_fail( IS_INFOBAR( object ) );
+
+	infobar = INFOBAR( object );
+
+	IM_FREEF( g_source_remove, infobar->close_timeout );
+	IM_FREEF( g_source_remove, infobar->close_animation_timeout );
+
+	GTK_OBJECT_CLASS( infobar_parent_class )->destroy( object );
+}
+
+static void
+infobar_class_init( InfobarClass *class )
+{
+	GtkObjectClass *object_class = (GtkObjectClass *) class;
+
+	infobar_parent_class = g_type_class_peek_parent( class );
+
+	object_class->destroy = infobar_destroy;
+}
+
+static void
+infobar_init( Infobar *infobar )
+{
+	infobar->label = NULL;
+	infobar->close_timeout = 0;
+	infobar->close_animation_timeout = 0;
+	infobar->height = 0;
+}
+
+GType
+infobar_get_type( void )
+{
+	static GType type = 0;
+
+	if( !type ) {
+		static const GTypeInfo info = {
+			sizeof( InfobarClass ),
+			NULL,           /* base_init */
+			NULL,           /* base_finalize */
+			(GClassInitFunc) infobar_class_init,
+			NULL,           /* class_finalize */
+			NULL,           /* class_data */
+			sizeof( Infobar ),
+			32,             /* n_preallocs */
+			(GInstanceInitFunc) infobar_init,
+		};
+
+		type = g_type_register_static( GTK_TYPE_INFO_BAR, 
+			"Infobar", &info, 0 );
+	}
+
+	return( type );
+}
+
+static void
+infobar_close( Infobar *infobar )
+{
+	IM_FREEF( g_source_remove, infobar->close_animation_timeout );
+	IM_FREEF( g_source_remove, infobar->close_timeout );
+	gtk_widget_hide( GTK_WIDGET( infobar ) );
+	gtk_widget_set_size_request( GTK_WIDGET( infobar ), -1, -1 );
+}
+
+static gboolean
+infobar_close_animation_timeout( Infobar *infobar )
+{
+	infobar->height -= 20;
+	if( infobar->height <= 0 ) {
+		infobar_close( infobar );
+		return( FALSE );
+	}
+	gtk_widget_set_size_request( GTK_WIDGET( infobar ), 
+		-1, infobar->height );
+
+	return( TRUE );
+}
+
+static void
+infobar_start_close( Infobar *infobar )
+{
+	IM_FREEF( g_source_remove, infobar->close_timeout );
+	IM_FREEF( g_source_remove, infobar->close_animation_timeout );
+	gtk_widget_set_size_request( GTK_WIDGET( infobar ), -1, -1 );
+
+	infobar->height = GTK_WIDGET( infobar )->allocation.height;
+	infobar->close_animation_timeout = g_timeout_add( 50, 
+		(GSourceFunc) infobar_close_animation_timeout, infobar );
+}
+
+static gboolean
+infobar_close_timeout( Infobar *infobar )
+{
+	infobar_start_close( infobar );
+
+	return( FALSE );
+}
+
+static void
+infobar_show( Infobar *infobar )
+{
+	IM_FREEF( g_source_remove, infobar->close_timeout );
+	IM_FREEF( g_source_remove, infobar->close_animation_timeout );
+	gtk_widget_set_size_request( GTK_WIDGET( infobar ), -1, -1 );
+	gtk_widget_show( GTK_WIDGET( infobar ) );
+
+	infobar->close_timeout = g_timeout_add( 5000, 
+		(GSourceFunc) infobar_close_timeout, infobar );
+}
+
+static void                
+infobar_response_cb( GtkInfoBar *info_bar, 
+	gint response_id, gpointer user_data )  
+{
+	infobar_start_close( INFOBAR( info_bar ) );
+}
+
+/* Make an infobar ... return NULL if our GTK doesn't have this thing.
+ */
+Infobar *
+infobar_new( void )
+{
+#ifdef USE_INFOBAR
+	Infobar *infobar;
+	GtkWidget *content_area;
+
+	infobar = g_object_new( TYPE_INFOBAR, NULL );
+	infobar->label = gtk_label_new( "" );
+        gtk_label_set_justify( GTK_LABEL( infobar->label ), GTK_JUSTIFY_LEFT );
+        gtk_label_set_selectable( GTK_LABEL( infobar->label ), TRUE );
+	gtk_label_set_line_wrap( GTK_LABEL( infobar->label ), TRUE );
+	content_area = gtk_info_bar_get_content_area( GTK_INFO_BAR( infobar ) );
+	gtk_container_add( GTK_CONTAINER( content_area ), infobar->label );
+	gtk_widget_show( infobar->label );
+	gtk_info_bar_add_button( GTK_INFO_BAR( infobar ),
+		 GTK_STOCK_OK, GTK_RESPONSE_OK );
+	g_signal_connect( infobar, "response",
+		G_CALLBACK( infobar_response_cb ), NULL );
+
+	return( infobar );
+#else /*!USE_INFOBAR*/
+	return( NULL );
+#endif /*USE_INFOBAR*/
+}
+
+/* Mark up a top/sub pair for an infobar.
+ */
+static void
+box_vmarkup_infobar( char *out, const char *top, const char *sub, va_list ap )
+{
+	char buf1[MAX_DIALOG_TEXT];
+	char buf2[MAX_DIALOG_TEXT];
+	char buf3[MAX_DIALOG_TEXT];
+	char *p;
+
+	escape_markup( top, buf1, MAX_DIALOG_TEXT );
+	(void) im_vsnprintf( buf2, MAX_DIALOG_TEXT, sub, ap );
+	escape_markup( buf2, buf3, MAX_DIALOG_TEXT );
+
+	(void) im_snprintf( out, MAX_DIALOG_TEXT, 
+		"<b>%s</b>", buf1 );
+	if( strcmp( buf3, "" ) != 0 ) {
+		int len = strlen( out );
+
+		(void) im_snprintf( out + len, MAX_DIALOG_TEXT - len, 
+			"\n%s", buf3 );
+	}
+
+	/* Remove any trailing newlines, they make infobars rather large.
+	 */
+	while( (p = out + strlen( out )) > out && p[-1] == '\n' )
+		p[-1] = '\0';
+}
+
+/* Set the label on an infobar to some marked-up text.
+ */
+void
+infobar_vset( Infobar *infobar, GtkMessageType type, 
+	const char *top, const char *sub, va_list ap )
+{
+	char buf[MAX_DIALOG_TEXT];
+
+	box_vmarkup_infobar( buf, top, sub, ap );
+	gtk_label_set_markup( GTK_LABEL( infobar->label ), buf );
+	gtk_info_bar_set_message_type( GTK_INFO_BAR( infobar ), type );
+
+	infobar_show( infobar );
+}
+
+/* Set the label on an infobar to some marked-up text.
+ */
+void
+infobar_set( Infobar *infobar, GtkMessageType type, 
+	const char *top, const char *sub, ... )
+{
+	va_list ap;
+
+        va_start( ap, sub );
+	infobar_vset( infobar, type, top, sub, ap );
+        va_end( ap );
+}
