@@ -147,19 +147,18 @@ classmodel_graphic_save( Classmodel *classmodel, GtkWidget *parent )
 {
 	ClassmodelClass *class = CLASSMODEL_GET_CLASS( classmodel );
 	GtkWidget *filesel;
-	VipsBuf buf;
 	char txt[100];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	if( !class->graphic_save ) {
 		error_top( _( "Not implemented." ) );
 		error_sub( _( "_%s() method not implemented for %s." ), 
 			"graphic_save", G_OBJECT_TYPE_NAME( classmodel ) );
-		box_alert( parent );
+		iwindow_alert( parent, GTK_MESSAGE_ERROR );
 		return;
 	}
 
 	filesel = filesel_new();
-	vips_buf_init_static( &buf, txt, 100 );
 	row_qualified_name( HEAPMODEL( classmodel )->row, &buf );
 	iwindow_set_title( IWINDOW( filesel ), _( "Save %s \"%s\"" ), 
 		G_OBJECT_TYPE_NAME( classmodel ), vips_buf_all( &buf ) );
@@ -221,19 +220,18 @@ classmodel_graphic_replace( Classmodel *classmodel, GtkWidget *parent )
 {
 	ClassmodelClass *class = CLASSMODEL_GET_CLASS( classmodel );
 	GtkWidget *filesel;
-	VipsBuf buf;
 	char txt[100];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	if( !class->graphic_replace ) {
 		error_top( _( "Not implemented." ) );
 		error_sub( _( "_%s() method not implemented for %s." ), 
 			"graphic_replace",
 			G_OBJECT_TYPE_NAME( classmodel ) );
-		box_alert( parent );
+		iwindow_alert( parent, GTK_MESSAGE_ERROR );
 		return;
 	}
 
-	vips_buf_init_static( &buf, txt, 100 );
 	row_qualified_name( HEAPMODEL( classmodel )->row, &buf );
 	filesel = filesel_new();
 	iwindow_set_title( IWINDOW( filesel ), _( "Replace %s \"%s\"" ), 
