@@ -123,11 +123,11 @@ build_vips_formats_sub( VipsFormatClass *format, GSList **types )
 {
 	FileselFileType *type = g_new( FileselFileType, 1 );
 	char txt[MAX_STRSIZE];
-	VipsBuf buf;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 	const char **i;
 
-	vips_buf_init_static( &buf, txt, MAX_STRSIZE );
-	vips_buf_appendf( &buf, "%s ", VIPS_OBJECT_CLASS( format )->description );
+	vips_buf_appendf( &buf, 
+		"%s ", VIPS_OBJECT_CLASS( format )->description );
 	/* Used as eg. "VIPS image files (*.v)"
 	 */
 	vips_buf_appends( &buf, _( "image files" ) );
@@ -352,6 +352,13 @@ filesel_jpeg_mode( char *out )
 
 		break;
 	}
+
+	case 2:
+		/* Don't attach a profile.
+		 */
+		im_snprintf( profile, FILENAME_MAX, ",none" );
+		break;
+
 	default:
 		/* Again, do nothing.
 		 */
@@ -495,9 +502,8 @@ filesel_space_update( Filesel *filesel, const char *dirname )
 				dirname );
 		else {
 			char txt[MAX_STRSIZE];
-			VipsBuf buf;
+			VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-			vips_buf_init_static( &buf, txt, MAX_STRSIZE );
 			to_size( &buf, sz );
 			vips_buf_appendf( &buf, " " );
 			/* Expands to (eg.) '6GB free in "/pics/tmp"'
@@ -580,8 +586,6 @@ filesel_dir_enter( Filesel *filesel )
 
 	if( !filesel->current_dir || 
 		(dir && strcmp( filesel->current_dir, dir ) != 0) ) {
-		if( filesel->browse )
-			browse_refresh( filesel->browse, dir );
 		filesel_space_update( filesel, dir );
 		if( !filesel->start_name )
 			IM_SETSTR( filesel_last_dir, dir );
@@ -606,11 +610,10 @@ filesel_current_folder_changed_cb( GtkWidget *widget, gpointer data )
 static void
 filesel_info_update( Filesel *filesel, const char *name )
 {
-	char txt[MAX_STRSIZE];
-	VipsBuf buf;
-
 	if( filesel->info ) {
-		vips_buf_init_static( &buf, txt, MAX_STRSIZE );
+		char txt[MAX_STRSIZE];
+		VipsBuf buf = VIPS_BUF_STATIC( txt );
+
 		get_image_info( &buf, name );
 		set_glabel( filesel->info, "%s", vips_buf_firstline( &buf ) );
 	}
@@ -844,26 +847,18 @@ filesel_auto_incr_cb( GtkWidget *tog, Filesel *filesel )
 		idialog_set_pinup( IDIALOG( filesel ), TRUE );
 }
 
-/* Popup a new browse window.
- */
-/*ARGSUSED*/
 static void
-browse_cb( GtkWidget *wid, Filesel *filesel )
+filesel_update_preview_cb( GtkFileChooser *chooser, Filesel *filesel )
 {
-        if( !filesel->browse ) {
-		char *dir;
+        char *filename;
 
-                filesel->browse = BROWSE( browse_new() );
-		browse_set_filesel( filesel->browse, filesel );
-		iwindow_build( IWINDOW( filesel->browse ) );
-		gtk_widget_show( GTK_WIDGET( filesel->browse ) );
+	if( (filename = gtk_file_chooser_get_preview_filename(
+		GTK_FILE_CHOOSER( filesel->chooser ) )) ) {
+		gtk_file_chooser_set_preview_widget_active(
+			GTK_FILE_CHOOSER( filesel->chooser ),
+			preview_set_filename( filesel->preview, filename ) );
 
-		if( (dir = filesel_get_dir( filesel )) ) {
-			browse_refresh( filesel->browse, dir );
-			g_free( dir );
-		}
-		else
-			box_alert( GTK_WIDGET( filesel ) );
+		g_free( filename );
 	}
 }
 
@@ -878,12 +873,12 @@ file_filter_from_file_type( FileselFileType *type )
 
 	if( type->suffixes[0] )
 		for( j = 0; type->suffixes[j]; j++ ) {
-			char buf[FILENAME_MAX];
-			VipsBuf patt;
+			char txt[FILENAME_MAX];
+			VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-			vips_buf_init_static( &patt, buf, FILENAME_MAX );
-			filesel_suffix_to_glob( type->suffixes[j], &patt );
-			gtk_file_filter_add_pattern( filter, vips_buf_all( &patt ) );
+			filesel_suffix_to_glob( type->suffixes[j], &buf );
+			gtk_file_filter_add_pattern( filter, 
+				vips_buf_all( &buf ) );
 		}
 	else
 		/* No suffix list means any suffix allowed.
@@ -918,7 +913,6 @@ filesel_build( GtkWidget *widget )
 	int i;
 	FileselFileType *type;
 	GtkWidget *vb;
-	GtkWidget *but;
 	GtkWidget *tog;
 
 #ifdef DEBUG
@@ -1003,23 +997,16 @@ filesel_build( GtkWidget *widget )
 			"file name" ) );
 	}
 
-        /* Browse thumbnails.
-         */
-        if( !filesel->save && filesel->imls ) {
-		GtkWidget *hb;
-
-		hb = gtk_hbox_new( FALSE, 3 );
-		gtk_box_pack_start( GTK_BOX( vb ), hb, FALSE, FALSE, 0 );
-		gtk_widget_show( hb );
-
-                but = gtk_button_new_with_label( _( "Show thumbnails" ) );
-                gtk_box_pack_end( GTK_BOX( hb ), but, FALSE, FALSE, 0 );
-                gtk_widget_show( but );
-                gtk_signal_connect( GTK_OBJECT( but ), "clicked",
-                        GTK_SIGNAL_FUNC( browse_cb ), filesel );
-		set_tooltip( but, 
-			_( "Show thumbnails for files in this directory" ) );
-        }
+        if( filesel->imls ) {
+		filesel->preview = preview_new();
+		gtk_file_chooser_set_preview_widget(
+			GTK_FILE_CHOOSER( filesel->chooser ), 
+			GTK_WIDGET( filesel->preview ) );
+		gtk_signal_connect( GTK_OBJECT( filesel->chooser ), 
+			"update-preview",
+			GTK_SIGNAL_FUNC( filesel_update_preview_cb ), filesel );
+		gtk_widget_show( GTK_WIDGET( filesel->preview ) );
+	}
 
 	if( filesel_last_dir ) 
 		gtk_file_chooser_set_current_folder(
@@ -1097,6 +1084,7 @@ filesel_init( Filesel *filesel )
 	filesel->chooser = NULL;
 	filesel->space = NULL;
 	filesel->info = NULL;
+	filesel->preview = NULL;
 	for( i = 0; i < FILESEL_MAX_FILTERS; i++ )
 		filesel->filter[i] = NULL;
 	filesel->incr = FALSE;
@@ -1104,7 +1092,6 @@ filesel_init( Filesel *filesel )
 	filesel->save = FALSE;
 	filesel->multi = FALSE;
 	filesel->start_name = FALSE;
-	filesel->browse = NULL;
 	filesel->type = NULL;
 	filesel->default_type = 0;
 	filesel->type_pref = NULL;
