@@ -60,7 +60,6 @@ typedef unsigned char EType;
 #define ELEMENT_MANAGED (11)	/* A managed object */
 #define ELEMENT_CONSTRUCTOR (12)/* Class constructor */
 #define ELEMENT_ELIST (13)	/* Empty list */
-#define ELEMENT_STATIC (14)	/* A static string */
 
 /* Flags we attach to a node.
  */
@@ -218,30 +217,31 @@ typedef struct pelement {
 #define PEISCONSTRUCTOR(P) (PEGETTYPE(P) == ELEMENT_CONSTRUCTOR)
 #define PEISCOMB(P) (PEGETTYPE(P) == ELEMENT_COMB)
 #define PEISCOMPLEX(P) (PEISNODE(P) && PEGETVAL(P)->type == TAG_COMPLEX)
-#define PEISELIST(P) (PEGETTYPE(P) == ELEMENT_ELIST)
-#define PEISFLIST(P) (PEISNODE(P) && PEGETVAL(P)->type == TAG_CONS)
 #define PEISTAG(P) (PEGETTYPE(P) == ELEMENT_TAG)
 #define PEISMANAGED(P) (PEGETTYPE(P) == ELEMENT_MANAGED)
 #define PEISMANAGEDGOBJECT(P) (PEISMANAGED(P) && \
 	IS_MANAGEDGOBJECT( PEGETVAL(P) ))
+#define PEISMANAGEDSTRING(P) (PEISMANAGED(P) && \
+	IS_MANAGEDSTRING(PEGETVAL(P)))
 #define PEISIMAGE(P) (PEISMANAGED(P) && IS_IMAGEINFO( PEGETVAL(P) ))
 #define PEISVIPSOBJECT(P) \
 	(PEISMANAGEDGOBJECT(P) && VIPS_IS_OBJECT( PEGETMANAGEDGOBJECT(P) )) 
-#define PEISFILE(P) (PEISMANAGED(P) && IS_MANAGEDFILE( PEGETVAL(P) ))
+#define PEISFILE(P) (PEISMANAGED(P) && IS_MANAGEDFILE(PEGETVAL(P)))
+#define PEISELIST(P) (PEGETTYPE(P) == ELEMENT_ELIST)
+#define PEISFLIST(P) ((PEISNODE(P) && PEGETVAL(P)->type == TAG_CONS) || \
+	PEISMANAGEDSTRING(P))
 #define PEISLIST(P) (PEISELIST(P) || PEISFLIST(P))
 #define PEISNOVAL(P) (PEGETTYPE(P) == ELEMENT_NOVAL)
 #define PEISNUM(P) (PEISREAL(P) || PEISCOMPLEX(P))
 #define PEISNODE(P) (PEGETTYPE(P) == ELEMENT_NODE)
 #define PEISREAL(P) (PEISNODE(P) && PEGETVAL(P)->type == TAG_DOUBLE)
 #define PEISSYMBOL(P) (PEGETTYPE(P) == ELEMENT_SYMBOL)
-#define PEISSTATIC(P) (PEGETTYPE(P) == ELEMENT_STATIC)
 #define PEISSYMREF(P) (PEGETTYPE(P) == ELEMENT_SYMREF)
 #define PEISCOMPILEREF(P) (PEGETTYPE(P) == ELEMENT_COMPILEREF)
 #define PEISUNOP(P) (PEGETTYPE(P) == ELEMENT_UNOP)
 
 /* Extract bits of primitive compound types.
  */
-#define PEGETSTATIC(P) ((HeapStaticString*)PEGETVAL(P))
 #define PEGETSYMBOL(P) ((Symbol*)PEGETVAL(P))
 #define PEGETSYMREF(P) ((Symbol*)PEGETVAL(P))
 #define PEGETCOMPILE(P) ((Compile*)(PEGETVAL(P)))
@@ -256,6 +256,7 @@ typedef struct pelement {
 #define PEGETII(P) ((Imageinfo*)PEGETVAL(P))
 #define PEGETFILE(P) ((Managedfile*)PEGETVAL(P))
 #define PEGETMANAGED(P) ((Managed*)PEGETVAL(P))
+#define PEGETMANAGEDSTRING(P) ((Managedstring*)PEGETVAL(P))
 #define PEGETMANAGEDGOBJECT(P) (((Managedgobject*)PEGETVAL(P))->object)
 #define PEGETVIPSOBJECT(P) \
 		((VipsObject*)(((Managedgobject*)PEGETVAL(P))->object))
@@ -279,17 +280,6 @@ struct _HeapBlock {
 	int sz;			/* Number of nodes in this block */
 };
 
-/* A static string. We compile these directly into the main heap and share
- * them between definitions.
- */
-typedef struct _HeapStaticString {
-	Heap *heap;		/* Heap we compiled into */
-
-	char *text;		/* Text of string */
-	int count;		/* Number of refs from Compiles to this */
-	Element e;		/* Points to compiled string */
-} HeapStaticString;
-
 /* Function to get max heap size.
  */
 typedef int (*heap_max_fn)( Heap * );
@@ -326,9 +316,13 @@ struct _Heap {
 	GHashTable *emark;	/* Set of elements to mark on GC */
 	GHashTable *rmark;	/* Set of Reduce to mark on GC */
 	GHashTable *mtable;	/* Managed associated with this heap */
-	GHashTable *statics;	/* Static string table */
 
         guint gc_tid;		/* id of gc delay timer */
+
+	/* Set this to force unreffed objects out immediately. Handy for leak 
+	 * testing.
+	 */
+	gboolean flush;
 };
 
 typedef struct _HeapClass {
@@ -400,6 +394,7 @@ gboolean heap_appl_add( Heap *heap, PElement *base, PElement *parm );
 gboolean heap_matrix_new( Heap *heap, 
 	int xsize, int ysize, double *vec, PElement *out );
 gboolean heap_string_new( Heap *heap, const char *str, PElement *out );
+gboolean heap_managedstring_new( Heap *heap, const char *str, PElement *out );
 gboolean heap_lstring_new( Heap *heap, GSList *labels, PElement *out );
 gboolean heap_file_new( Heap *heap, const char *filename, PElement *out );
 
@@ -410,6 +405,7 @@ void *heap_map_list( PElement *base, heap_map_list_fn fn, void *a, void *b );
 typedef void *(*heap_map_dict_fn)( const char *, PElement *, void *a, void *b );
 void *heap_map_dict( PElement *base, heap_map_dict_fn fn, void *a, void *b );
 
+gboolean heap_get_list( PElement *list );
 gboolean heap_get_list_next( PElement *list, PElement *data );
 gboolean heap_get_string( PElement *base, char *buf, int n );
 gboolean heap_get_lstring( PElement *base, GSList **labels );
@@ -439,8 +435,5 @@ gboolean heap_reduce_strict( PElement *base );
 
 gboolean heap_copy( Heap *heap, Compile *compile, PElement *out );
 
-HeapStaticString *heap_static_string_new( Heap *heap, const char *text );
-void *heap_static_string_unref( HeapStaticString *string );
-
 gboolean heap_ip_to_gvalue( PElement *in, GValue *out );
 gboolean heap_gvalue_to_ip( GValue *in, PElement *out );
