@@ -104,10 +104,10 @@ typedef struct _Undobuffer {
  * the IMAGE and gets zapped by the imageinfo on dispose. This lets us spot
  * IMAGE events after the holding Imageinfo has gone.
  */
-typedef struct _ImageinfoIMAGE {
+typedef struct _Imageinfoproxy {
 	IMAGE *im;
 	Imageinfo *imageinfo;
-} ImageinfoIMAGE;
+} Imageinfoproxy;
 
 /* A VIPS image wrapped up nicely.
  */
@@ -118,7 +118,7 @@ struct _Imageinfo {
 	IMAGE *mapped_im;	/* Cache image mapped-thru-lut here */
 	IMAGE *identity_lut;	/* For base images, keep an id lut if poss */
 	Imageinfo *underlying;	/* If we're a LUT, the image we are a LUT of */
-	ImageinfoIMAGE *proxy;	/* Proxy for IMAGE callbacks */
+	Imageinfoproxy *proxy;	/* Proxy for IMAGE callbacks */
 
 	gboolean dfile;		/* delete_file on final close */
 
@@ -141,12 +141,9 @@ struct _Imageinfo {
 	GSList *redo;			/* List of redo buffers */
 	Undobuffer *cundo;		/* Current buffer */
 
-	/* A progress dialog popped up for eval on this ->im.
+	/* Have we attached progress stuff to this ii?
 	 */
-	gboolean monitored;		/* Have we attached callbacks */
-	double eval_last;		/* When we last updated */
-	Progress *eval_progress;	/* The progress box */
-	GtkWidget *eval_parent;		/* ... as child of */
+	gboolean monitored;
 
 	/* If we're from a file, the timestamp on the file we loaded from ...
 	 * used to spot changes.
@@ -158,7 +155,9 @@ struct _Imageinfo {
 typedef struct _ImageinfoClass {
 	ManagedClass parent_class;
 
-	/* An area of the screen needs repainting.
+	/* An area of the screen needs repainting. This can happen for regions
+	 * being dragged, for example, and doesn't always mean pixels have
+	 * changed.
 	 */
 	void (*area_changed)( Imageinfo *, Rect * );
 
@@ -167,6 +166,12 @@ typedef struct _ImageinfoClass {
 	 */
 	void (*area_painted)( Imageinfo *, Rect * );
 
+	/* Our IMAGE* has signaled "invalidate". This can happen indirectly:
+	 * if we paint on an image, im_invalidate() will trigger on that image
+	 * and all derived images.
+	 */
+	void (*invalidate)( Imageinfo * );
+
 	/* Update undo/redo button sensitivities.
 	 */
 	void (*undo_changed)( Imageinfo * );
@@ -190,10 +195,7 @@ Imageinfo *imageinfo_new( Imageinfogroup *imageinfogroup,
 	Heap *heap, IMAGE *im, const char *name );
 Imageinfo *imageinfo_new_temp( Imageinfogroup *imageinfogroup, 
 	Heap *heap, const char *name, const char *mode );
-Imageinfo *imageinfo_new_lut( Imageinfogroup *imageinfogroup, 
-	Heap *heap, Imageinfo *imageinfo );
-Imageinfo *imageinfo_new_modlut( Imageinfogroup *imageinfogroup, 
-	Heap *heap, Imageinfo *imageinfo, IMAGE *im );
+void imageinfo_set_underlying( Imageinfo *top_imageinfo, Imageinfo *imageinfo );
 gboolean imageinfo_is_from_file( Imageinfo *imageinfo );
 Imageinfo *imageinfo_new_input( Imageinfogroup *imageinfogroup, 
 	GtkWidget *parent, Heap *heap, const char *name );
@@ -201,8 +203,7 @@ Imageinfo *imageinfo_new_input( Imageinfogroup *imageinfogroup,
 IMAGE *imageinfo_get( gboolean use_lut, Imageinfo *imageinfo );
 gboolean imageinfo_same_underlying( Imageinfo *imageinfo[], int n );
 
-gboolean imageinfo_write( Imageinfo *imageinfo, 
-	GtkWidget *parent, const char *filename );
+gboolean imageinfo_write( Imageinfo *imageinfo, const char *filename );
 gboolean imageinfo_check_paintable( Imageinfo *imageinfo, 
 	GtkWidget *parent, iWindowNotifyFn nfn, void *sys );
 
@@ -235,7 +236,7 @@ gboolean imageinfo_paint_text( Imageinfo *imageinfo,
 gboolean imageinfo_paint_mask( Imageinfo *imageinfo, 
 	Imageinfo *ink, Imageinfo *mask, int x, int y );
 
-void imageinfo_to_text( Imageinfo *imageinfo, BufInfo *buf );
+void imageinfo_to_text( Imageinfo *imageinfo, VipsBuf *buf );
 gboolean imageinfo_from_text( Imageinfo *imageinfo, const char *text );
 void imageinfo_to_rgb( Imageinfo *imageinfo, double *rgb );
 void imageinfo_from_rgb( Imageinfo *imageinfo, double *rgb );
