@@ -99,9 +99,6 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif /*HAVE_UNISTD_H*/
-#ifdef HAVE_REGEX_H
-#include <regex.h>
-#endif /*HAVE_REGEX_H*/
 #ifdef HAVE_SYS_STATVFS_H
 #include <sys/statvfs.h>
 #endif /*HAVE_SYS_STATVFS_H*/
@@ -128,7 +125,32 @@ extern int statfs();
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
+#ifdef HAVE_LIBGOFFICE
+#include <goffice/goffice.h>
+
+#include <goffice/app/go-plugin.h>
+#include <goffice/app/go-plugin-loader-module.h>
+
+#include <goffice/data/go-data-simple.h>
+
+#include <goffice/graph/gog-data-set.h>
+#include <goffice/graph/gog-label.h>
+#include <goffice/graph/gog-object.h>
+#include <goffice/graph/gog-plot.h>
+#include <goffice/graph/gog-series.h>
+#include <goffice/graph/gog-grid.h>
+#include <goffice/graph/gog-grid-line.h>
+#include <goffice/graph/gog-legend.h>
+#include <goffice/graph/gog-chart-map.h>
+
+#include <goffice/gtk/go-graph-widget.h>
+
+#include <goffice/utils/go-color.h>
+#include <goffice/utils/go-marker.h>
+#endif /*HAVE_LIBGOFFICE*/
+
 #include <vips/vips.h>
+#include <vips/debug.h>
 
 #include <libxml/tree.h>
 #include <libxml/parser.h>
@@ -144,8 +166,6 @@ extern int statfs();
 /* Our general widgets.
  */
 #include "formula.h"
-#include "orderitem.h"
-#include "orderlist.h"
 #include "doubleclick.h"
 
 /* Generated marshallers.
@@ -164,7 +184,7 @@ extern int statfs();
 #define VIPS_HOMEPAGE "http://www.vips.ecs.soton.ac.uk"
 #define IP_NAME PACKAGE "-" VERSION
 #define NIP_DOCPATH "$VIPSHOME" G_DIR_SEPARATOR_S "share" G_DIR_SEPARATOR_S \
-        "doc" G_DIR_SEPARATOR_S IP_NAME G_DIR_SEPARATOR_S "html"
+        "doc" G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "html"
 #define VIPS_DOCPATH "$VIPSHOME" G_DIR_SEPARATOR_S "share" G_DIR_SEPARATOR_S \
 	"doc" G_DIR_SEPARATOR_S "vips" G_DIR_SEPARATOR_S "html"
 #define IP_NAME PACKAGE "-" VERSION
@@ -287,6 +307,8 @@ typedef struct _Toolkitgroupview Toolkitgroupview;
 typedef struct _Toolkitview Toolkitview;
 typedef struct _Toolview Toolview;
 typedef struct _Trace Trace;
+typedef struct _Preview Preview;
+typedef struct _Infobar Infobar;
 typedef struct _iError iError;
 typedef struct _Log Log;
 typedef struct _vObject vObject;
@@ -317,7 +339,6 @@ typedef void *(*tool_map_fn)( Tool *, void *, void * );
  */
 #include "util.h"
 #include "gtkutil.h"
-#include "wild.h"
 #include "path.h"
 #include "iobject.h"
 #include "icontainer.h"
@@ -396,7 +417,7 @@ typedef void *(*tool_map_fn)( Tool *, void *, void * );
 #include "statusview.h"
 #include "plotstatus.h"
 #include "mainw.h"
-#include "browse.h"
+#include "preview.h"
 #include "builtin.h"
 #include "compile.h"
 #include "dump.h"
@@ -421,7 +442,9 @@ typedef void *(*tool_map_fn)( Tool *, void *, void * );
 #include "matrix.h"
 #include "matrixview.h"
 #include "plot.h"
+#ifdef HAVE_LIBGOFFICE
 #include "plotview.h"
+#endif /*HAVE_LIBGOFFICE*/
 #include "plotmodel.h"
 #include "plotpresent.h"
 #include "plotwindow.h"
