@@ -47,7 +47,8 @@
  */
 
 /* But some themes can trigger warnings, argh, so sometimes we need to
- * undef it. VipsObject sets can also trigger warnings.
+ * undef it. VipsObject sets can trigger warnings. libgoffice will warn about
+ * precision issues if run under valgrind.
  */
 #undef DEBUG_FATAL
 
@@ -155,8 +156,7 @@ static GOptionEntry main_option[] = {
 /* Accumulate startup errors here.
  */
 static char main_start_error_txt[MAX_STRSIZE];
-static VipsBuf main_start_error = 
-	VIPS_BUF_STATIC( main_start_error_txt, MAX_STRSIZE );
+static VipsBuf main_start_error = VIPS_BUF_STATIC( main_start_error_txt );
 
 static void
 main_log_add( const char *fmt, ... )
@@ -207,10 +207,9 @@ main_error_exit( const char *fmt, ... )
 		error_get_top(), error_get_sub() );
 
 	if( main_option_verbose ) {
-		VipsBuf buf;
 		char txt[MAX_STRSIZE];
+		VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-		vips_buf_init_static( &buf, txt, MAX_STRSIZE );
 		slist_map( expr_error_all,
 			(SListMapFn) expr_error_print, &buf );
 		fprintf( stderr, "%s\n", vips_buf_all( &buf ) );
@@ -338,6 +337,13 @@ main_quit( void )
 	if( main_icon_factory )
 		gtk_icon_factory_remove_default( main_icon_factory );
 
+#ifdef HAVE_LIBGOFFICE
+	/* Not quite sure what this does, but don't do it in batch mode.
+ 	 */
+	if( !main_option_batch )
+		libgoffice_shutdown ();
+#endif /*HAVE_LIBGOFFICE*/
+
 	/* Should have freed everything now.
 	 */
 
@@ -352,9 +358,6 @@ main_quit( void )
 	managed_check_all_destroyed();
 	util_check_all_destroyed();
 	vips_check_all_destroyed();
-#ifdef HAVE_VIPS8
-	vips_object_print_all();
-#endif /*HAVE_VIPS8*/
 
 #ifdef PROFILE
 	g_mem_profile();
@@ -413,7 +416,7 @@ main_watchgroup_changed_cb( void )
 }
 
 /* Try to load a thing, anything at all. Actually, we don't load plugins
- * experimentally: win32 pops up an annoying error dialog if you try that.
+ * experimentally, win32 pops up an annoying error dialog if you try that.
  */
 gboolean
 main_load( Workspace *ws, const char *filename )
@@ -464,7 +467,7 @@ main_load_plug( char *name )
 		error_top( _( "Unable to load." ) );
 		error_sub( _( "Error loading plug-in \"%s\"." ), name );
 		error_vips();
-		box_alert( NULL );
+		iwindow_alert( NULL, GTK_MESSAGE_ERROR );
 	}
 
 	return( NULL );
@@ -481,7 +484,7 @@ main_load_def( const char *filename )
 
 		if( !(kit = toolkit_new_from_file( main_toolkitgroup, 
 			filename )) )
-			box_alert( NULL );
+			iwindow_alert( NULL, GTK_MESSAGE_ERROR );
 		else 
 			filemodel_set_auto_load( FILEMODEL( kit ) );
 	}
@@ -501,7 +504,7 @@ main_load_ws( const char *filename )
 	progress_update_loading( 0, im_skip_dir( filename ) );
 
 	if( !(ws = workspace_new_from_file( main_workspacegroup, filename )) ) 
-		box_alert( NULL );
+		iwindow_alert( NULL, GTK_MESSAGE_ERROR );
 	else {
 		filemodel_set_auto_load( FILEMODEL( ws ) );
 	}
@@ -773,6 +776,12 @@ main_x_init( int *argc, char ***argv )
 			"ipgtkrc", NULL, NULL, NULL );
 	gtk_init( argc, argv );
 
+#ifdef HAVE_LIBGOFFICE
+        libgoffice_init();
+	go_plugins_init( NULL, NULL, NULL, NULL, TRUE, 
+		GO_TYPE_PLUGIN_LOADER_MODULE );
+#endif /*HAVE_LIBGOFFICE*/
+
 	/* Set the default icon. 
 	 */
 	expand_variables( "$VIPSHOME/share/$PACKAGE/data/vips-128.png", buf );
@@ -860,14 +869,12 @@ main_check_temp( double total )
 {
 	if( total > 10 * 1024 * 1024 ) {
 		char txt[256];
-		VipsBuf buf;
+		VipsBuf buf = VIPS_BUF_STATIC( txt );
 		char tmp[FILENAME_MAX];
 
 		expand_variables( PATH_TMP, tmp );
 		nativeize_path( tmp );
 		absoluteize_path( tmp );
-
-		vips_buf_init_static( &buf, txt, 256 );
 		to_size( &buf, total );
 
 		box_yesno( NULL,
@@ -966,7 +973,7 @@ main( int argc, char *argv[] )
 #endif /*HAVE_FFTW*/
 	Toolkit *kit;
 	char txt[MAX_STRSIZE];
-	VipsBuf buf;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 #ifdef DEBUG_LEAK
 #ifdef PROFILE
@@ -1050,11 +1057,6 @@ main( int argc, char *argv[] )
 	 */
 	setenvf( "SEP", "%s", G_DIR_SEPARATOR_S );
 
-#ifdef HAVE_VIPS8
-	if( !vips_init( &argc, &argv, &error ) ) 
-		vfatal( &error );
-#endif /*HAVE_VIPS8*/
-
 	/* Start up vips.
 	 */
 	if( im_init_world( main_argv0 ) )
@@ -1081,10 +1083,6 @@ main( int argc, char *argv[] )
 	/* Don't start X here! We may be in batch mode.
 	 */
 	g_option_context_add_group( context, gtk_get_option_group( FALSE ) );
-
-#ifdef HAVE_VIPS8
-	g_option_context_add_group( context, vips_get_option_group() );
-#endif /*HAVE_VIPS8*/
 	g_option_context_add_group( context, im_get_option_group() );
 
 	if( !g_option_context_parse( context, &argc, &argv, &error ) ) 
@@ -1304,7 +1302,6 @@ main( int argc, char *argv[] )
 	if( main_option_expression ) {
 		kit = toolkit_new( main_toolkitgroup, "_expression" );
 
-		vips_buf_init_static( &buf, txt, MAX_STRSIZE );
 		vips_buf_appendf( &buf, "main = %s;", main_option_expression );
 		attach_input_string( vips_buf_all( &buf ) );
 		(void) parse_onedef( kit, -1 );
@@ -1347,6 +1344,18 @@ main( int argc, char *argv[] )
 	 */
 	symbol_recalculate_all_force( TRUE );
 
+	/* Pass PATH_TMP down to vips via TMPDIR. See im_system(), for
+	 * example. We need to do this after the first recomp so that prefs
+	 * are loaded.
+	 */
+{
+	char buf[FILENAME_MAX];
+
+	expand_variables( PATH_TMP, buf );
+	nativeize_path( buf );
+	setenvf( "TMPDIR", "%s", buf );
+}
+
 	/* Measure amount of stuff in temp area ... need this for checking
 	 * temps later. We pop a dialog if there are too many, so only useful
 	 * in interactive mode.
@@ -1357,12 +1366,12 @@ main( int argc, char *argv[] )
 	/* Make nip's argc/argv[].
 	 */
 	kit = toolkit_new( main_toolkitgroup, "_args" );
-	vips_buf_init_static( &buf, txt, MAX_STRSIZE );
+	vips_buf_rewind( &buf );
 	vips_buf_appendf( &buf, "argc = %d;", argc );
 	attach_input_string( vips_buf_all( &buf ) );
 	(void) parse_onedef( kit, -1 );
 
-	vips_buf_init_static( &buf, txt, MAX_STRSIZE );
+	vips_buf_rewind( &buf );
 	vips_buf_appendf( &buf, "argv = [" );
 	for( i = 0; i < argc; i++ ) {
 		if( i > 0 )
@@ -1403,8 +1412,6 @@ main( int argc, char *argv[] )
 				main_log_add( "%s\n", error_get_sub() );
 	}
 
-	/* Recalc to load any args.
-	 */
 	symbol_recalculate_all_force( TRUE );
 
 	/* Make sure our start ws doesn't have modified set. We may have
@@ -1432,7 +1439,7 @@ main( int argc, char *argv[] )
 
 		/* Process a few events ... we want the window to be mapped so
 		 * that log/welcome/clean? messages we pop appear in the right
-		 * place on the srceen.
+		 * place on the screen.
 		 */
 		while( g_main_context_iteration( NULL, FALSE ) )
 			;
@@ -1446,7 +1453,7 @@ main( int argc, char *argv[] )
 			error_top( _( "Startup error." ) );
 			error_sub( _( "Startup error log:\n%s" ), 
 				main_log_get() );
-			box_alert( NULL );
+			iwindow_alert( NULL, GTK_MESSAGE_ERROR );
 		}
 
 		if( welcome_message ) {
@@ -1457,14 +1464,15 @@ main( int argc, char *argv[] )
 				_( "Welcome to %s-%s!" ), PACKAGE, VERSION );
 			expand_variables( get_savedir(), save_dir );
 			nativeize_path( save_dir );
-			box_info( NULL, 
-				buf,
+			error_top( "%s", buf );
+			error_sub( 
 _( "A new directory has been created in your home directory to hold startup, "
 "data and temporary files:\n\n"
 "     %s\n\n"
 "If you've used previous versions of %s, you will probably want "
 "to move any files over from your old work area and remove any old temps." ),
 				save_dir, PACKAGE );
+			iwindow_alert( NULL, GTK_MESSAGE_INFO );
 		}
 
 		/* Offer to junk temps.
