@@ -40,7 +40,9 @@ extern void *main_c_stack_base;			/* Base of C stack */
 
 extern gboolean main_starting;			/* In startup */
 
-extern gboolean main_time_save;			/* Time save image ops */
+extern gboolean main_option_time_save;		/* Time save image ops */
+extern gboolean main_option_i18n;		/* Output i18n strings */
+extern gboolean main_option_batch;		/* Running in batch mode */
 
 /* Styles for buttons etc.
  */
@@ -54,6 +56,7 @@ extern GtkStyle *dirty_style;
 
 void main_quit_test( void );
 void main_reload( void );
-void main_splash_update( const char *fmt, ... );
+void main_splash_update( const char *fmt, ... )
+	__attribute__((format(printf, 1, 2)));
 gboolean main_load( Workspace *ws, const char *filename );
 
