@@ -166,14 +166,14 @@ mainw_compat_timeout( Mainw *mainw )
 {
 	mainw->compat_timeout = 0;
 
-	box_info( GTK_WIDGET( mainw ),
-		_( "Compatibility mode." ),
-		_( "This workspace was created by version %d.%d.%d. "
+	error_top( _( "Compatibility mode." ) );
+	error_sub( _( "This workspace was created by version %d.%d.%d. "
 		"A set of compatibility menus have been loaded "
 		"for this window." ),
 		FILEMODEL( mainw->ws )->major,
 		FILEMODEL( mainw->ws )->minor,
 		FILEMODEL( mainw->ws )->micro );
+	iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_INFO );
 
 	return( FALSE );
 }
@@ -185,6 +185,9 @@ mainw_map( GtkWidget *widget )
 
 	g_assert( !mainw->compat_timeout );
 
+	/* Popping up the info dialog immediately gives us stacking problems
+	 * :(
+	 */
 	if( mainw->ws->compat_major )
 		mainw->compat_timeout = g_timeout_add( 500, 
 			(GSourceFunc) mainw_compat_timeout, mainw );
@@ -339,9 +342,8 @@ mainw_find_disc( VipsBuf *buf )
 		vips_buf_appendf( buf, _( "No temp area" ) );
 	else {
 		char txt[MAX_STRSIZE];
-		VipsBuf buf2;
+		VipsBuf buf2 = VIPS_BUF_STATIC( txt );
 
-		vips_buf_init_static( &buf2, txt, MAX_STRSIZE );
 		to_size( &buf2, sz );
 		vips_buf_appendf( buf, _( "%s free" ), vips_buf_all( &buf2 ) );
 	}
@@ -366,9 +368,7 @@ mainw_free_update( Mainw *mainw )
 {
 	Heap *heap = reduce_context->heap;
 	char txt[80];
-	VipsBuf buf;
-
-	vips_buf_init_static( &buf, txt, 80 );
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	if( workspace_selected_any( mainw->ws ) ) {
 		/* Display select message instead.
@@ -395,10 +395,9 @@ mainw_free_update( Mainw *mainw )
 static void
 mainw_title_update( Mainw *mainw )
 {
-	VipsBuf buf;
 	char txt[512];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-	vips_buf_init_static( &buf, txt, 512 );
 	if( FILEMODEL( mainw->ws )->modified ) 
 		vips_buf_appendf( &buf, "*" ); 
 	vips_buf_appendf( &buf, "%s", NN( IOBJECT( mainw->ws->sym )->name ) );
@@ -461,9 +460,8 @@ mainw_jump_build( Column *column, GtkWidget *menu )
 {
 	GtkWidget *item;
 	char txt[256];
-	VipsBuf buf;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-	vips_buf_init_static( &buf, txt, 256 );
 	vips_buf_appendf( &buf, "%s - %s", 
 		IOBJECT( column )->name, IOBJECT( column )->caption );
 	item = gtk_menu_item_new_with_label( vips_buf_all( &buf ) );
@@ -654,7 +652,7 @@ mainw_clone( Mainw *mainw )
 		Row *row = workspace_get_bottom( ws );
 
 		if( !row ) {
-			box_alert( GTK_WIDGET( mainw ) );
+			iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 			return;
 		}
 		row_select( row );
@@ -664,7 +662,7 @@ mainw_clone( Mainw *mainw )
 	 */
 	progress_begin();
 	if( !workspace_clone_selected( ws ) ) { 
-		box_alert( GTK_WIDGET( mainw ) );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 		progress_end();
 		return;
 	}
@@ -688,7 +686,7 @@ mainw_ungroup_action_cb( GtkAction *action, Mainw *mainw )
 {
 	progress_begin();
 	if( !workspace_selected_ungroup( mainw->ws ) )
-		box_alert( GTK_WIDGET( mainw ) );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 	progress_end();
 }
 
@@ -698,8 +696,8 @@ static void
 mainw_group_action_cb( GtkAction *action, Mainw *mainw )
 {
 	Workspace *ws = mainw->ws;
-	VipsBuf buf;
 	char txt[MAX_STRSIZE];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	if( !workspace_selected_any( ws ) ) {
 		/* Nothing selected -- select bottom object.
@@ -707,18 +705,17 @@ mainw_group_action_cb( GtkAction *action, Mainw *mainw )
 		Row *row = workspace_get_bottom( ws );
 
 		if( !row ) {
-			box_alert( GTK_WIDGET( mainw ) );
+			iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 			return;
 		}
 		row_select( row );
 	}
 
-	vips_buf_init_static( &buf, txt, MAX_STRSIZE );
 	vips_buf_appends( &buf, "Group [" );
 	workspace_selected_names( ws, &buf, "," );
 	vips_buf_appends( &buf, "]" );
 	if( !workspace_add_def( ws, vips_buf_all( &buf ) ) ) {
-		box_alert( GTK_WIDGET( mainw ) );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 		return;
 	}
 	workspace_deselect_all( ws );
@@ -743,7 +740,7 @@ mainw_find_action_cb( GtkAction *action, Mainw *mainw )
 {
 	error_top( _( "Not implemented." ) );
 	error_sub( _( "Find in workspace not implemented yet." ) );
-	box_alert( GTK_WIDGET( mainw ) );
+	iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_INFO );
 }
 
 static void
@@ -751,7 +748,7 @@ mainw_find_again_action_cb( GtkAction *action, Mainw *mainw )
 {
 	error_top( _( "Not implemented." ) );
 	error_sub( _( "Find again in workspace not implemented yet." ) );
-	box_alert( GTK_WIDGET( mainw ) );
+	iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_INFO );
 }
 
 static Row *
@@ -779,15 +776,16 @@ mainw_test_error( Row *row, Mainw *mainw, int *found )
 static void
 mainw_next_error_action_cb( GtkAction *action, Mainw *mainw )
 {
-	VipsBuf buf;
-	char str[MAX_LINELENGTH];
+	char txt[MAX_LINELENGTH];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	int found;
 
 	if( !mainw->ws->errors ) {
-		box_info( GTK_WIDGET( mainw ), _( "No errors." ), 
-			_( "There are no errors (that I can see) "
+		error_top( _( "No errors." ) );
+		error_sub( "%s", _( "There are no errors (that I can see) "
 			"in this workspace." ) );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_INFO );
 		return;
 	}
 
@@ -811,7 +809,6 @@ mainw_next_error_action_cb( GtkAction *action, Mainw *mainw )
 
 	model_scrollto( MODEL( mainw->row_last_error ), MODEL_SCROLL_TOP );
 
-	vips_buf_init_static( &buf, str, MAX_LINELENGTH );
 	row_qualified_name( mainw->row_last_error->expr->row, &buf );
 	vips_buf_appends( &buf, ": " );
 	vips_buf_appends( &buf, mainw->row_last_error->expr->error_top );
@@ -847,10 +844,9 @@ mainw_force_calc_action_cb( GtkAction *action, Mainw *mainw )
 	Workspace *ws = mainw->ws;
 
         if( workspace_selected_any( ws ) ) {
-		VipsBuf buf;
-		char str[30];
+		char txt[30];
+		VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-		vips_buf_init_static( &buf, str, 30 );
 		workspace_selected_names( ws, &buf, ", " );
 
 		box_yesno( GTK_WIDGET( mainw ), 
@@ -973,10 +969,9 @@ mainw_open_done_cb( iWindow *iwnd, void *client,
 	Filesel *filesel = FILESEL( iwnd );
 	int nselected = filesel_nselected( filesel );
 	char txt[MAX_STRSIZE];
-	VipsBuf buf;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 	MainwLoad load;
 
-	vips_buf_init_static( &buf, txt, MAX_STRSIZE );
 	load.mainw = mainw;
 	load.buf = &buf;
 	load.nitems = 0;
@@ -999,7 +994,8 @@ mainw_open_done_cb( iWindow *iwnd, void *client,
 		mainw->ws &&
 		!workspace_add_def( mainw->ws, vips_buf_all( &buf ) ) ) {
 		error_top( _( "Load failed." ) );
-		error_sub( _( "Unable to execute:\n   %s" ), vips_buf_all( &buf ) );
+		error_sub( _( "Unable to execute:\n   %s" ), 
+			vips_buf_all( &buf ) );
 		nfn( sys, IWINDOW_ERROR );
 		return;
 	}
@@ -1099,7 +1095,7 @@ mainw_recent_open_cb( GtkWidget *widget, const char *filename )
 
 	progress_begin();
 	if( !mainw_recent_open( mainw, filename ) ) {
-		box_alert( widget );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 		progress_end();
 		return;
 	}
@@ -1117,10 +1113,9 @@ mainw_recent_build( GtkWidget *menu, GSList *recent )
 		const char *filename = (const char *) p->data;
 		GtkWidget *item;
 		char txt[80];
-		VipsBuf buf;
+		VipsBuf buf = VIPS_BUF_STATIC( txt );
 		char *utf8;
 
-		vips_buf_init_static( &buf, txt, 80 );
 		vips_buf_appendf( &buf, "    %s", im_skip_dir( filename ) );
 		utf8 = f2utf8( vips_buf_all( &buf ) );
 		item = gtk_menu_item_new_with_label( utf8 );
@@ -1275,7 +1270,7 @@ mainw_workspace_duplicate_action_cb( GtkAction *action, Mainw *mainw )
         progress_begin();
 	if( !(new_ws = workspace_clone( mainw->ws )) ) {
 		progress_end();
-		box_alert( GTK_WIDGET( mainw ) );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 		return;
 	}
 	symbol_recalculate_all();
@@ -1303,7 +1298,7 @@ mainw_workspace_merge_action_cb2( GtkWidget *wid, GtkWidget *host,
 static void
 mainw_recover_action_cb( GtkAction *action, Mainw *mainw )
 {
-	workspace_auto_recover( GTK_WIDGET( mainw ) );
+	workspace_auto_recover( mainw );
 }
 
 /* Callback from make new column.
@@ -1316,7 +1311,7 @@ mainw_column_new_action_cb( GtkAction *action, Mainw *mainw )
 
 	name = workspace_column_name_new( mainw->ws, NULL );
 	if( !(col = column_new( mainw->ws, name )) ) 
-		box_alert( GTK_WIDGET( mainw ) );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 	else
 		workspace_column_select( mainw->ws, col );
 	IM_FREE( name );
@@ -1532,7 +1527,7 @@ mainw_preferences_action_cb( GtkAction *action, Mainw *mainw )
 	/* Can fail if there's no prefs ws, or an error on load.
 	 */
 	if( !(prefs = prefs_new( NULL )) ) {
-		box_alert( GTK_WIDGET( mainw ) );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 		return;
 	}
 
@@ -1568,11 +1563,11 @@ mainw_magic_cb( gpointer callback_data, guint callback_action,
 	Row *row = workspace_selected_one( ws );
 
 	if( !row )
-		box_info( GTK_WIDGET( mainw ),
+		box_alert( mainw,
 			"Select a single object with left-click, "
 			"select Magic Definition." );
 	else if( !magic_sym( row->sym ) )
-		box_alert( GTK_WIDGET( mainw ) );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 	else
 		workspace_deselect_all( ws );
 }
@@ -1976,6 +1971,13 @@ mainw_build( iWindow *iwnd, GtkWidget *vbox )
 	gtk_box_pack_start( GTK_BOX( vbox ), mainw->toolbar, FALSE, FALSE, 0 );
         widget_visible( mainw->toolbar, MAINW_TOOLBAR );
 
+	/* This will set to NULL if we don't have infobar support.
+	 */
+	if( (IWINDOW( mainw )->infobar = infobar_new()) ) 
+		gtk_box_pack_start( GTK_BOX( vbox ), 
+			GTK_WIDGET( IWINDOW( mainw )->infobar ), 
+			FALSE, FALSE, 0 );
+
 	/* hbox for status bar etc.
 	 */
         mainw->statusbar_main = gtk_hbox_new( FALSE, 2 );
