@@ -55,6 +55,13 @@ struct _Mainw {
 	guint heap_changed_sid;
 	guint watch_changed_sid;
 
+	/* Link to progress system.
+	 */
+	guint begin_sid;	
+	guint update_sid;	
+	guint end_sid;	
+	gboolean cancel;
+
 	/* Display MB free in tmp, or cells free in heap.
 	 */
 	gboolean free_type;
@@ -94,6 +101,8 @@ struct _Mainw {
 	GtkWidget *statusbar;
 	GtkWidget *space_free;	
 	GtkWidget *space_free_eb;	
+	GtkWidget *progress_box;
+	GtkWidget *progress;
 
 	/* Left and right panes ... program window and toolkit browser.
 	 */
@@ -114,6 +123,8 @@ extern GSList *mainw_recent_matrix;
 
 extern gboolean mainw_auto_recalc;
 
+extern gboolean mainw_cancel;
+
 void mainw_startup( void );
 void mainw_shutdown( void );
 void mainw_recent_freeze( void );
@@ -125,6 +136,9 @@ Mainw *mainw_pick_one( void );
 GType mainw_get_type( void );
 void mainw_about_action_cb( GtkAction *action, iWindow *iwnd );
 void mainw_guide_action_cb( GtkAction *action, iWindow *iwnd );
-Filemodel *mainw_open_file( Mainw *mainw, const char *filename );
+Workspace *mainw_open_file_into_workspace( Mainw *mainw, const char *filename );
 Mainw *mainw_new( Workspace *ws );
 
+void busy_progress( int percent, int eta );
+void busy_begin( void );
+void busy_end( void );
