@@ -190,10 +190,10 @@ symbol_qualified_name_relative( Symbol *context, Symbol *sym, VipsBuf *buf )
 const char *
 symbol_name( Symbol *sym )
 {
-	static VipsBuf buf;
 	static char txt[200];
+	static VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-	vips_buf_init_static( &buf, txt, 200 );
+	vips_buf_rewind( &buf );
 	symbol_qualified_name( sym, &buf );
 
 	return( vips_buf_all( &buf ) );
@@ -215,10 +215,10 @@ symbol_name_scope( Symbol *sym )
 {
 	Symbol *scope = symbol_get_scope( sym );
 
-	static VipsBuf buf;
 	static char txt[200];
+	static VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-	vips_buf_init_static( &buf, txt, 200 );
+	vips_buf_rewind( &buf );
 	vips_buf_appends( &buf, NN( IOBJECT( scope )->name ) );
 	vips_buf_appends( &buf, "." );
 	symbol_qualified_name_relative( scope, sym, &buf );
@@ -481,14 +481,13 @@ void
 symbol_not_defined( Symbol *sym )
 {
 	char txt[256];
-	VipsBuf buf;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	error_top( _( "Not found." ) );
-	vips_buf_init_static( &buf, txt, 256 );
 	vips_buf_appendf( &buf, _( "Symbol %s is not defined." ), 
 		symbol_name( sym ) );
-	vips_buf_appends( &buf, "\n" );
 	if( sym->topparents ) {
+		vips_buf_appends( &buf, "\n" );
 		vips_buf_appendf( &buf, _( "%s is referred to by" ),
 			symbol_name( sym ) );
 		vips_buf_appends( &buf, ": " );
@@ -701,10 +700,10 @@ symbol_new( Compile *compile, const char *name )
 void
 symbol_error_redefine( Symbol *sym )
 {
-	static VipsBuf buf;
 	static char txt[200];
+	static VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-	vips_buf_init_static( &buf, txt, 200 );
+	vips_buf_rewind( &buf );
 	vips_buf_appendf( &buf, _( "Redefinition of \"%s\"." ), 
 		IOBJECT( sym )->name );
 	if( sym->tool && sym->tool->lineno != -1 ) {
@@ -976,7 +975,11 @@ symbol_recalculate_check( Symbol *sym )
 {
 #ifdef DEBUG_RECALC
 	printf( "symbol_recalculate_check: %s\n", symbol_name_scope( sym ) );
-	g_assert( symbol_is_leafable( sym ) );
+
+	/* We can symbol_recalculate_check() syms which are not dirty.
+	 */
+	g_assert( !sym->dirty || symbol_is_leafable( sym ) );
+
 	g_assert( symbol_ndirty( sym ) == 0 );
 #endif /*DEBUG_RECALC*/
 
@@ -1026,7 +1029,8 @@ symbol_recalculate_check( Symbol *sym )
 		expr_new_value( sym->expr );
 
 #ifdef DEBUG_RECALC
-		printf( "\t(success)\n" ); 
+		printf( "\tsuccess: " ); 
+		graph_pointer( &sym->expr->root );
 #endif /*DEBUG_RECALC*/
 	}
 #ifdef DEBUG_RECALC
