@@ -45,7 +45,7 @@ static GSList *trace_all = NULL;
 
 /* Trace buffer stack.
  */
-static BufInfo trace_buffer_stack[SPINE_SIZE];
+static VipsBuf trace_buffer_stack[SPINE_SIZE];
 static int trace_buffer_stack_p = 0;
 
 /* Number of active trace blocks.
@@ -79,7 +79,7 @@ trace_get_trace_flag( GtkAction *action )
 		if( strcmp( name, trace_types[i].name ) == 0 )
 			return( trace_types[i].flag );
 
-	assert( FALSE );
+	g_assert( FALSE );
 }
 
 void
@@ -93,7 +93,7 @@ trace_unblock( void )
 {
 	trace_block_count -= 1;
 
-	assert( trace_block_count >= 0 );
+	g_assert( trace_block_count >= 0 );
 }
 
 void
@@ -102,7 +102,7 @@ trace_reset( void )
 	int i;
 
 	for( i = 0; i < trace_buffer_stack_p; i++ )
-		buf_destroy( &trace_buffer_stack[i] );
+		vips_buf_destroy( &trace_buffer_stack[i] );
 
 	trace_buffer_stack_p = 0;
 }
@@ -110,10 +110,10 @@ trace_reset( void )
 void
 trace_check( void )
 {
-	assert( trace_buffer_stack_p == 0 );
+	g_assert( trace_buffer_stack_p == 0 );
 }
 
-BufInfo *
+VipsBuf *
 trace_push( void )
 {
 	int i;
@@ -129,7 +129,7 @@ trace_push( void )
 	}
 
 	i = trace_buffer_stack_p++;
-	buf_init_dynamic( &trace_buffer_stack[i], MAX_TRACE );
+	vips_buf_init_dynamic( &trace_buffer_stack[i], MAX_TRACE );
 
 	return( &trace_buffer_stack[i] );
 }
@@ -143,16 +143,16 @@ trace_pop( void )
 	printf( "trace_pop: %d\n", trace_buffer_stack_p );
 #endif 
 
-	assert( trace_buffer_stack_p > 0 );
+	g_assert( trace_buffer_stack_p > 0 );
 
 	i = --trace_buffer_stack_p;
-	buf_destroy( &trace_buffer_stack[i] );
+	vips_buf_destroy( &trace_buffer_stack[i] );
 }
 
-BufInfo *
+VipsBuf *
 trace_current( void )
 {
-	assert( trace_buffer_stack_p > 0 );
+	g_assert( trace_buffer_stack_p > 0 );
 
 	return( &trace_buffer_stack[trace_buffer_stack_p - 1] );
 }
@@ -166,7 +166,7 @@ trace_get_mark( void )
 void
 trace_pop_to( int n )
 {
-	assert( n >= 0 && n <= trace_buffer_stack_p );
+	g_assert( n >= 0 && n <= trace_buffer_stack_p );
 
 	while( trace_buffer_stack_p > n ) 
 		trace_pop();
@@ -398,7 +398,7 @@ trace_text( TraceFlags flags, const char *fmt, ... )
 void
 trace_pelement( PElement *pe )
 {
-	BufInfo *buf = trace_current();
+	VipsBuf *buf = trace_current();
 	Heap *heap = reduce_context->heap;
 
 	graph_pelement( heap, buf, pe, TRACE_FUNCTIONS );
@@ -418,7 +418,7 @@ trace_node( HeapNode *node )
 void
 trace_args( HeapNode **arg, int n )
 {
-	BufInfo *buf = trace_current();
+	VipsBuf *buf = trace_current();
 	int i;
 
 	for( i = n - 1; i >= 0; i-- ) {
@@ -426,44 +426,44 @@ trace_args( HeapNode **arg, int n )
 
 		PEPOINTRIGHT( arg[i], &rhs );
 		trace_pelement( &rhs ); 
-		buf_appends( buf, " " ); 
+		vips_buf_appends( buf, " " ); 
 	}
 
-	buf_appendf( buf, "->\n" ); 
+	vips_buf_appendf( buf, "->\n" ); 
 }
 
 void
 trace_binop( Compile *compile, PElement *left, BinOp bop, PElement *right )
 {
-	BufInfo *buf = trace_current();
+	VipsBuf *buf = trace_current();
 
-	buf_appendf( buf, "\"%s\" ", decode_BinOp( bop ) );
+	vips_buf_appendf( buf, "\"%s\" ", decode_BinOp( bop ) );
 	trace_pelement( left );
-	buf_appends( buf, " " );
+	vips_buf_appends( buf, " " );
 	trace_pelement( right );
-	buf_appends( buf, " -> (" );
+	vips_buf_appends( buf, " -> (" );
 	compile_name( compile, buf );
-	buf_appends( buf, ")\n" );
+	vips_buf_appends( buf, ")\n" );
 }
 
 void
 trace_uop( UnOp uop, PElement *arg )
 {
-	BufInfo *buf = trace_current();
+	VipsBuf *buf = trace_current();
 
-	buf_appendf( buf, "\"%s\" ", decode_UnOp( uop ) );
+	vips_buf_appendf( buf, "\"%s\" ", decode_UnOp( uop ) );
 	trace_pelement( arg );
-	buf_appends( buf, " ->\n" ); 
+	vips_buf_appends( buf, " ->\n" ); 
 }
 
 void
 trace_result( TraceFlags flags, PElement *out )
 {
-	BufInfo *buf = trace_current();
+	VipsBuf *buf = trace_current();
 
-	buf_appendf( buf, "    " ); 
+	vips_buf_appendf( buf, "    " ); 
 	trace_pelement( out );
-	buf_appends( buf, "\n" ); 
+	vips_buf_appends( buf, "\n" ); 
 
-	trace_text( flags, buf_all( buf ) ); 
+	trace_text( flags, "%s", vips_buf_all( buf ) ); 
 }
