@@ -512,10 +512,9 @@ Symbol *
 workspace_load_file( Workspace *ws, const char *filename )
 {
 	char txt[MAX_STRSIZE];
-	VipsBuf buf;
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 	Symbol *sym;
 
-	vips_buf_init_static( &buf, txt, MAX_STRSIZE );
 	if( !workspace_load_file_buf( &buf, filename ) )
 		return( NULL );
 	if( !(sym = workspace_add_def( ws, vips_buf_all( &buf ) )) ) 
@@ -752,7 +751,7 @@ workspace_auto_recover_load( iWindow *iwnd,
  * retain_files[] set.
  */
 void
-workspace_auto_recover( GtkWidget *parent )
+workspace_auto_recover( Mainw *mainw )
 {
 	char *p;
 	char *name;
@@ -762,7 +761,7 @@ workspace_auto_recover( GtkWidget *parent )
 	/* Find the dir we are saving temp files to.
 	 */
 	if( !temp_name( buf, "ws" ) ) {
-		box_alert( parent );
+		iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_ERROR );
 		return;
 	}
 
@@ -773,17 +772,20 @@ workspace_auto_recover( GtkWidget *parent )
 	(void) path_map_dir( buf, "*.ws", 
 		(path_map_fn) workspace_test_file, buf2 );
 	if( date_sofar == -1 ) {
-		if( !AUTO_WS_SAVE )
-			box_info( parent, 
-				_( "No backup workspaces found." ),
+		if( !AUTO_WS_SAVE ) {
+			error_top( _( "No backup workspaces found." ) );
+			error_sub( "%s", 
 				_( "You need to enable \"Auto workspace "
 				"save\" in Preferences "
 				"before automatic recovery works." ) );
-		else
-			box_info( parent, 
-				_( "No backup workspaces found." ),
-				_( "No suitable workspace save files found "
+			iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_INFO );
+		}
+		else {
+			error_top( _( "No backup workspaces found." ) );
+			error_sub( _( "No suitable workspace save files found "
 				"in \"%s\"" ), buf );
+			iwindow_alert( GTK_WIDGET( mainw ), GTK_MESSAGE_INFO );
+		}
 
 		return;
 	}
@@ -792,7 +794,7 @@ workspace_auto_recover( GtkWidget *parent )
 	 */
 	name = im_strdupn( buf2 );
 
-	box_yesno( parent, 
+	box_yesno( GTK_WIDGET( mainw ), 
 		workspace_auto_recover_load, iwindow_true_cb, name, 
 		(iWindowNotifyFn) im_free, name,
 		GTK_STOCK_OPEN, 
@@ -1096,7 +1098,7 @@ static void *
 workspace_load_toolkit( const char *filename, Toolkitgroup *toolkitgroup )
 {
 	if( !toolkit_new_from_file( toolkitgroup, filename ) ) 
-		box_alert( NULL );
+		iwindow_alert( NULL, GTK_MESSAGE_ERROR );
 
 	return( NULL );
 }
@@ -1215,12 +1217,13 @@ workspace_top_load( Filemodel *filemodel,
 		 */
 		if( state->major != filemodel->major ||
 			state->minor != filemodel->minor ) {
-			box_info( NULL,
-				_( "Version mismatch." ),
-				_( "File \"%s\" was saved from %s-%d.%d.%d. "
+			error_top( _( "Version mismatch." ) );
+			error_sub( _( "File \"%s\" was saved from %s-%d.%d.%d. "
 				"You may see compatibility problems." ),
 				state->filename, PACKAGE,
 				state->major, state->minor, state->micro );
+			iwindow_alert( GTK_WIDGET( ws->iwnd ), 
+				GTK_MESSAGE_INFO );
 		}
 
 		break;
@@ -1572,12 +1575,11 @@ workspace_add_action( Workspace *ws,
 	const char *name, const char *action, int nparam )
 {
 	Column *col = workspace_column_pick( ws );
-	char str[1024];
-	VipsBuf buf;
+	char txt[1024];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
 	/* Are there any selected symbols?
 	 */
-	vips_buf_init_static( &buf, str, 1024 );
 	vips_buf_appends( &buf, action );
 	if( nparam > 0 && workspace_selected_any( ws ) ) {
 		if( nparam != workspace_selected_num( ws ) ) {
@@ -1772,13 +1774,12 @@ workspace_selected_remove_yesno_cb( iWindow *iwnd, void *client,
 void
 workspace_selected_remove_yesno( Workspace *ws, GtkWidget *parent )
 {
-	VipsBuf buf;
-	char str[30];
+	char txt[30];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
         if( !workspace_selected_any( ws ) ) 
 		return;
 
-	vips_buf_init_static( &buf, str, 30 );
 	workspace_selected_names( ws, &buf, ", " );
 
 	box_yesno( parent, 
@@ -1794,10 +1795,10 @@ workspace_selected_remove_yesno( Workspace *ws, GtkWidget *parent )
 static gboolean
 workspace_ungroup_add_index( Row *row, const char *fmt, int i )
 {
-	static VipsBuf buf;
 	static char txt[200];
+	static VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-	vips_buf_init_static( &buf, txt, 200 );
+	vips_buf_rewind( &buf );
 	row_qualified_name( row, &buf );
 	vips_buf_appendf( &buf, fmt, i );
 	if( !workspace_add_def( row->ws, vips_buf_all( &buf ) ) )
@@ -1840,10 +1841,9 @@ workspace_ungroup_row( Row *row )
 					return( row );
 		}
 		else {
-			VipsBuf buf;
 			char txt[100];
+			VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-			vips_buf_init_static( &buf, txt, 100 );
 			row_qualified_name( row, &buf );
 			error_top( _( "Unable to ungroup." ) );
 			error_sub( _( "Row \"%s\" is not a Group or a list." ), 
