@@ -468,12 +468,12 @@ workspaceview_drag_data_received( GtkWidget *widget, GdkDragContext *context,
 
 		name = workspace_column_name_new( ws, NULL );
 		if( !(col = column_new( ws, name )) )
-			box_alert( widget );
+			iwindow_alert( widget, GTK_MESSAGE_ERROR );
 		IM_FREE( name );
 
 		if( col ) {
 			char vips_buf_text[256];
-			VipsBuf buf;
+			VipsBuf buf = VIPS_BUF_STATIC( vips_buf_text );
 			Symbol *sym;
 
 			col->x = x;
@@ -483,13 +483,12 @@ workspaceview_drag_data_received( GtkWidget *widget, GdkDragContext *context,
 			/* Qualify relative to us. We don't want to embed
 			 * workspace names unless we have to.
 			 */
-			vips_buf_init_static( &buf, vips_buf_text, 256 );
 			row_qualified_name_relative( ws->sym, 
 				from_row, &buf );
 
 			if( !(sym = workspace_add_def( ws, 
 				vips_buf_all( &buf ) )) ) 
-				box_alert( widget );
+				iwindow_alert( widget, GTK_MESSAGE_ERROR );
 
 			symbol_recalculate_all();
 
